core

package
v1.13.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 7, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

the core package provides basic functionality to all the major components of the code

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CorrectPassword

func CorrectPassword(input, hash string) bool

func Hash

func Hash(input string) string

func RandomBoardName

func RandomBoardName() string

func Sanitize

func Sanitize(s string) string

Sanitize ensures strings only contain letters and numbers

func UUID4

func UUID4() string

UUID4 makes and sanitizes a new uuid

Types

This section is empty.

Directories

Path Synopsis
the core package provides basic functionality to all the major components of the code
the core package provides basic functionality to all the major components of the code

Jump to