Documentation
¶
Index ¶
- type Coord
- type CoordSet
- func (cs CoordSet) Add(c *Coord)
- func (cs CoordSet) AddAll(ds CoordSet)
- func (cs CoordSet) Equal(other CoordSet) bool
- func (cs CoordSet) Has(c *Coord) bool
- func (cs CoordSet) Intersect(ds CoordSet) CoordSet
- func (cs CoordSet) IsSubsetOf(other CoordSet) bool
- func (cs CoordSet) List() []*Coord
- func (cs CoordSet) Remove(c *Coord)
- func (cs CoordSet) RemoveAll(ds CoordSet)
- func (cs CoordSet) String() string
- type Diff
- type Stone
- type StoneSet
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Coord ¶
Coord is just an (x,y) coordinate pair
func FromAlphanumeric ¶
FromAlphanumeric converts a string like "c17" to a Coord
func FromInterface ¶
InterfaceToCoord essentially coerces the interface into a [2]int then turns that into a Coord
func FromLetters ¶
FromLetters takes a pair of letters and turns it into a Coord
type CoordSet ¶
CoordSet is used for quickly checking a set for existence of coords
func (CoordSet) IsSubsetOf ¶
IsSubsetOf checks for set inclusion
type Diff ¶
Diff contains two StoneSets (Add and Remove) and is a key component of a Frame
type StoneSet ¶
StoneSet is an array of Coords plus a Color
func NewStoneSet ¶
NewStoneSet takes a CoordSet and a Color and turns it into a StoneSet
Click to show internal directories.
Click to hide internal directories.